==> redux-arena-0.7.1.tgz: package/es/hocs/SceneBundle/SceneBundle.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from "react";
import PropTypes from "prop-types";

var SceneBundle = function (_Component) {
  _inherits(SceneBundle, _Component);

  function SceneBundle() {
    _classCallCheck(this, SceneBundle);

    return _possibleConstructorReturn(this, _Component.apply(this, arguments));
  }

  SceneBundle.prototype.getChildContext = function getChildContext() {
    return {
      arenaReducerDict: this.props.reduxInfo.arenaReducerDict
    };
  };

  SceneBundle.prototype.componentWillMount = function componentWillMount() {
    var _this2 = this;

    this.setState({
      isSceneBundleValid: false,
      initialPromoise: new Promise(function (resolve) {
        setImmediate(function () {
          _this2.loadScene(_this2.props, true);
          resolve(true);
        });
      })
    });
  };

  SceneBundle.prototype.componentWillUnmount = function componentWillUnmount() {
    if (this.props.isNotifyOn) {
      this.props.sceneStopPlay(this.props.parentArenaReducerDict, this.props.sceneBundle, this.props.asyncSceneBundle, this.props.notifyData);
    }
  };

  SceneBundle.prototype.checkAndStartPlay = function checkAndStartPlay(props, nextProps) {
    if (nextProps.PlayingScene != null && nextProps.PlayingScene !== props.PlayingScene) {
      this.setState({
        isSceneBundleValid: true
      }, function () {
        if (nextProps.isNotifyOn) {
          nextProps.sceneStartPlay(nextProps.parentArenaReducerDict, nextProps.sceneBundle, nextProps.asyncSceneBundle, nextProps.notifyData);
        }
      });
    }
  };

  SceneBundle.prototype.componentDidMount = function componentDidMount() {
    this.checkAndStartPlay({}, this.props);
  };

  SceneBundle.prototype.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    var _this3 = this;

    var asyncSceneBundle = nextProps.asyncSceneBundle,
        sceneBundle = nextProps.sceneBundle;

    this.checkAndStartPlay(this.props, nextProps);
    if (asyncSceneBundle !== this.props.asyncSceneBundle || sceneBundle !== this.props.sceneBundle) {
      this.state.initialPromoise.then(function () {
        return _this3.loadScene(nextProps, false);
      });
    }
    if (nextProps.PlayingScene == null) {
      this.setState({
        isSceneBundleValid: false
      });
    }
  };

  SceneBundle.prototype.loadScene = function loadScene(props, isInitial) {
    if (props.isNotifyOn) {
      props.sceneLoadStart(props.parentArenaReducerDict, props.sceneBundle, props.asyncSceneBundle, props.notifyData, isInitial);
    }
    props.arenaLoadScene(props.parentArenaReducerDict, props.sceneBundle, props.asyncSceneBundle, props.notifyData, isInitial);
  };

  SceneBundle.prototype.render = function render() {
    var _props = this.props,
        PlayingScene = _props.PlayingScene,
        sceneProps = _props.sceneProps;

    if (this.state.isSceneBundleValid) {
      return React.createElement(PlayingScene, sceneProps);
    } else {
      return React.createElement("div", null);
    }
  };

  return SceneBundle;
}(Component);

SceneBundle.propTypes = {
  asyncSceneBundle: PropTypes.any,
  sceneBundle: PropTypes.object,
  sceneProps: PropTypes.object,
  isNotifyOn: PropTypes.bool,
  notifyData: PropTypes.object
};
SceneBundle.defaultProps = {
  isNotifyOn: false
};
SceneBundle.childContextTypes = {
  arenaReducerDict: PropTypes.object
};
export default SceneBundle;

==> redux-arena-0.8.0.tgz: package/es/hocs/SceneBundle/SceneBundle.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from "react";
import PropTypes from "prop-types";

var SceneBundle = function (_Component) {
  _inherits(SceneBundle, _Component);

  function SceneBundle() {
    _classCallCheck(this, SceneBundle);

    return _possibleConstructorReturn(this, _Component.apply(this, arguments));
  }

  SceneBundle.prototype.getChildContext = function getChildContext() {
    return {
      arenaReducerDict: this.props.reduxInfo.arenaReducerDict
    };
  };

  SceneBundle.prototype.buildLoadScenePromise = function buildLoadScenePromise(arenaReducerDict, sceneBundle, isInitial) {
    var _this2 = this;

    if (isInitial) {
      return new Promise(function (resolve) {
        return setImmediate(function () {
          return _this2.props.arenaLoadScene(_this2.props.arenaReducerDict, _this2.props.sceneBundle, true, resolve);
        });
      });
    } else {
      return new Promise(function (resolve) {
        return _this2.props.arenaLoadScene(_this2.props.arenaReducerDict, _this2.props.sceneBundle, true, resolve);
      });
    }
  };

  SceneBundle.prototype.componentWillMount = function componentWillMount() {
    var loadedPromise = this.buildLoadScenePromise(this.props.arenaReducerDict, this.props.sceneBundle, true);
    this.setState({
      loadedPromise: loadedPromise
    });
  };

  SceneBundle.prototype.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    var _this3 = this;

    var sceneBundle = nextProps.sceneBundle;

    if (sceneBundle !== this.props.sceneBundle) {
      this.state.loadedPromise.then(function () {
        var loadedPromise = _this3.buildLoadScenePromise(nextProps.arenaReducerDict, nextProps.sceneBundle, false);
        _this3.setState({
          loadedPromise: loadedPromise
        });
      });
    }
  };

  SceneBundle.prototype.componentWillUnmount = function componentWillUnmount() {
    this.props.clearCurtain();
    this.props.mutableObj.isObsolete = true;
  };

  SceneBundle.prototype.render = function render() {
    var _props = this.props,
        PlayingScene = _props.PlayingScene,
        sceneProps = _props.sceneProps;

    if (PlayingScene != null) {
      return React.createElement(PlayingScene, sceneProps);
    } else {
      return React.createElement("div", null);
    }
  };

  return SceneBundle;
}(Component);

SceneBundle.propTypes = {
  sceneBundle: PropTypes.object.isRequired,
  sceneProps: PropTypes.object
};
SceneBundle.childContextTypes = {
  arenaReducerDict: PropTypes.object
};
export default SceneBundle;
